import path from "node:path";
import { bundle } from "lightningcss";
function returnAST(source) {
  let ast = null;
  try {
    bundle({
      filename: path.join(__dirname, source),
      drafts: {
        customMedia: true
      },
      visitor: {
        StyleSheet(stylesheet) {
          ast = stylesheet;
        }
      }
    });
    return ast;
  } catch (error) {
    throw Error(
      `[@sardine/lightningcss-plugin-global-custom-queries]: ${error.message}`
    );
  }
}
const globalCustomQueries = ({ source }) => {
  const ast = returnAST(source);
  if (!ast) {
    throw Error(
      `[@sardine/lightningcss-plugin-global-custom-queries]: The file "${source}" does not contain valid CSS.`
    );
  }
  return {
    MediaQuery(query) {
      var _a;
      if (((_a = query == null ? void 0 : query.condition) == null ? void 0 : _a.type) === "feature" && query.condition.value.name.startsWith("--")) {
        const matchedConditionValue = query.condition.value;
        let resolvedQuery = null;
        for (const rule of ast.rules) {
          if (rule.type === "custom-media" && rule.value.name === matchedConditionValue.name) {
            resolvedQuery = rule.value.query.mediaQueries[0];
            break;
          }
        }
        if (resolvedQuery == null ? void 0 : resolvedQuery.condition) {
          query.condition = resolvedQuery.condition;
        }
      }
      return query;
    }
  };
};
export {
  globalCustomQueries as default
};
